@@ -22,12 +22,12 @@ from gettext import gettext as _
 assembly_title = _('Furius ISO Mount Tool')
 assembly_description = _('''Simple Gtk+ Interface to Mount ISO, IMG, BIN, MDF and NRG Image files without burning to disk.''')
 assembly_website = 'https://launchpad.net/furiusisomount/'
-assembly_version = '0.11.1.2'
+assembly_version = '0.11.2.1'
 assembly_name = 'furiusisomount'
 
 # Directories
 home_directory = os.path.expanduser('~')
-settings_directory = os.path.join(home_directory, '.FuriusIsoMount')
+settings_directory = os.path.join(home_directory, '.furiusisomount')
 source_directory = os.path.join(os.path.dirname(__file__))
 resource_directory = os.path.join(source_directory, '..', 'res')
 image_directory = os.path.join(source_directory, '..', 'pix')
@@ -41,4 +41,5 @@ mount_log = os.path.join(settings_directory, 'FuriusMountLog.txt')
 mount_list = os.path.join(settings_directory, 'FuriusMountList.csv')
 history_list = os.path.join(settings_directory, 'FuriusMountHistory.txt')
 image_burn_button = os.path.join(image_directory, 'imageburn.png')
-image_checksum_button = os.path.join(image_directory, 'imagechecksum.png')
\ No newline at end of file
+image_checksum_button = os.path.join(image_directory, 'imagechecksum.png')
+settings_file = os.path.join(settings_directory, 'settings.cfg')
\ No newline at end of file
